clear      
clear mata
clear matrix                                                                                                            
set more off
capture log close
set scheme s2color
local graphr "graphr(fc(white) lc(white) ifc(white) ilc(white))" 
local grcom "ycommon xcommon imargin(zero)"
local pointer "msi(zero) mcol(white) mlabp(6) mlabc(white) mlabs(medlarge)"
local stdl_spike "lc(gs12) lp(solid) lw(vvthin)"
# delimit ; 
program drop _all;
program diff, rclass;
qui sum support if(treatcue==1); local treat = r(mean);
qui sum support if(treatcue==0); local control = r(mean);
return scalar diff = `treat' - `control';
end;

ssc install outreg2, replace;
ssc install mmodes, replace;
ssc install outtable, replace;

program diff_overall, rclass;
qui {; forval c = 1/3 {;
sum support if(treatcue==1&ctry_num==`c'); 
if(r(N)==0){; local t`c' = 0; local Nt`c' = 0; }; 
else {; local t`c' = r(mean); local Nt`c' = r(N); }; 
sum support if(treatcue==0&ctry_num==`c'); 
if(r(N)==0){; local c`c' = 0; local Nc`c' = 0; };   
else {; local c`c' = r(mean); local Nc`c' = r(N); }; }; 
sum support; local N = r(N); }; 
return scalar diff = ((`t1' - `c1')*(`Nt1' + `Nc1') + 
(`t2' - `c2')*(`Nt2' + `Nc2') + (`t3' - `c3')*(`Nt3' + `Nc3'))/`N';
end;
*=================================================================================================;
*=================================================================================================;
*=================================================================================================; 
* File-Name:	BraderTuckerDuell_replicationFile.do                               
* Data Used:    BraderTuckerDuell_data.dta
*=================================================================================================;
*=================================================================================================;
* Description of variables
*=================================================================================================;
* Main variables
**************
* ctry            				Country name: gb, hu, po (great britain, hungary, poland)
* ctry_num        				Numeric country ID: 1 = GB, 2 = Hungary, 3 = Poland
* respondentid					Unique respondent identifier
* treatcue						Dummy treated: party-cue received
* support         				Support for policy
* party_age       				Party age
* party_sys_age   				Party age relative to system age
* incumbent       				Dummy incumbent party
* idcoh           				Ideological coherence: std dev of left-right placements of party
* idcohpar        				Ideological coherence: std dev of left-right placements of party by partisans
* idcohprefpar    				Ideological coherence: std dev of left-right placement of own party by partisans
* benoitlaver     				Ideolgocial coherence: Benoit/Laver variation estimate of manifesto data of part
* partisan        				Dummy partisan identifier
* treatcue        				Dummy treated: party-cue received
* party_old       				Dummy old party
* party_sys_old   				Dummy old party relative to system age
* ambiguous_high  				Dummy high ideological ambiguity
* hu              				Dummy Hungary
* po              				Dummy Poland
**************
* Interactions
**************
* treathu         				Dummy Hungary and treatment                
* treatpo         				Dummy Poland and treatment                   
* treatinc                      Dummy treated and dummy incumbent party    
* treatidcohpar   				Dummy treated and ideological coherence 
* treatparty_age  				Dummy treated and party age 
* treatparty_sys_age            Dummy treated and party age relative to system age    
* treatincidcohpar              Dummy treated, dummy incumbent party, and ideological coherence   
* treatparty_ageidcohpar        Dummy treated, party age, and ideological coherence         
* treatparty_sys_ageidcohpar    Dummy treated, party age relative to system, and ideological coherence            
* incidcohpar    				Dummy incumbent party and ideological coherence  
* party_ageidcohpar             Party age and ideological coherence  
* party_sys_ageidcohpar			Party age relative to system and ideological coherence
*=================================================================================================;
*=================================================================================================;
* Table 1 Summary Statistics 
*=================================================================================================;
use BraderTuckerDuell_CPS2013_data, clear;

* Percentage of partisans in sample by country;
bysort ctry: sum partisan; 

* Table with summary statistics of included variables by ctry for partisans;
keep if(partisan==1);

tempname descriptives; postfile `descriptives' mean se median mode N var ctry
using descriptives, replace;
forval c = 1/3 {;
foreach v in support treatcue party_age party_sys_age incumbent idcohpar {; 
if("`v'"=="support"){; local var = 1; }; 
else if("`v'"=="treatcue"){; local var = 2; };
else if("`v'"=="party_age"){; local var = 3; };
else if("`v'"=="party_sys_age"){; local var = 4; };
else if("`v'"=="incumbent"){; local var = 5; }; 
else if("`v'"=="idcohpar"){; local var = 6; };
******************************************************************************;
qui {; sum `v' if(ctry_num==`c'), d; local mean = r(mean); local se = r(sd);
local N = r(N); local median = r(p50); 
preserve; keep if(ctry_num==`c'); mmodes `v'; local mode = r(mean); restore; };
******************************************************************************;
post `descriptives' (`mean') (`se') (`median') (`mode') (`N') (`var') (`c'); 
}; }; 
foreach v in support treatcue party_age party_sys_age incumbent idcohpar {;
if("`v'"=="support"){; local var = 1; }; 
else if("`v'"=="treatcue"){; local var = 2; };
else if("`v'"=="party_age"){; local var = 3; };
else if("`v'"=="party_sys_age"){; local var = 4; };
else if("`v'"=="incumbent"){; local var = 5; }; 
else if("`v'"=="idcohpar"){; local var = 6; };
******************************************************************************;
qui {; sum `v', d; local mean = r(mean); local se = r(sd);
local N = r(N); local median = r(p50); mmodes `v'; local mode = r(mean); }; 
******************************************************************************;
post `descriptives' (`mean') (`se') (`median') (`mode') (`N') (`var') (0); 
}; 
******************************************************************************;
postclose `descriptives';
******************************************************************************;

use descriptives, clear; 
forval c = 0/3 {; if(`c'==0){; local name "full"; };
else if(`c'==1){; local name "gb"; };
else if(`c'==2){; local name "hu"; };
else if(`c'==3){; local name "po"; };
mkmat mean se median mode N if(ctry==`c'&var<=6), mat(sum_stats); 
mat coln sum_stats = "Mean" "SE" "Median" "Mode" "N";
mat rown sum_stats = "Support" "Treated" "Party_Age" "Party_Age_(System)" 
"Incumbent" "Ambiguity"; 
mat list sum_stats; 
outtable using table1_`name', 
mat(sum_stats) nobox  f(%6.4g) replace center 
caption(Summary Statistics for `name'-sample); };

erase "descriptives.dta";

*=================================================================================================;
* Figure 1-5: Means and average treatment effects of level of support by country and by categories
* (incumbent vs opposition party, old vs new party, old vs new party relative to party system age,
* ideological ambiguous vs coherent party) for control versus treatment group 
*=================================================================================================;
use data, clear;
keep if(partisan==1);

******************************************************************************;
* Figure 1-5, left panel: Means of level of support 
******************************************************************************;
* Generating quantities of interest;
tempname means; postfile `means' mean lb ub N var t cat ctry
using means, replace;
******************************************************************************;
forval c = 1/3 {; forval t = 0/1 {;
di "ctry:`c', treatment:`t'";
******************************************************************************;
qui bs mean = r(mean), reps(100) seed(010101) 
level(90): sum support if(ctry_num==`c'&treatcue==`t'); 
mat ci = e(ci_percentile); local lb = ci[1,1]; local ub = ci[2,1]; 
mat mean = e(b); local mean = mean[1,1]; mat N = e(N); local N = N[1,1]; 
******************************************************************************;
post `means' (`mean') (`lb') (`ub') (`N') (0) (`t') (.) (`c');  
******************************************************************************;
foreach v in incumbent party_old party_sys_old ambiguous_high {; 
if("`v'"=="incumbent"){; local V = 1; local range "0/1"; };
else if("`v'"=="party_old"){; local V = 2; local range "0/1"; 
if(`c'>=2){; local range "0/0"; }; else {; local range "0/1"; }; };
else if("`v'"=="party_sys_old"){; local V = 3; 
if(`c'==2){; local range "1/1"; }; else {; local range "0/1"; }; }; 
else if("`v'"=="ambiguous_high"){; local V = 4; 
if(`c'==2){; local range "0/0"; }; else {; local range "0/1"; }; }; 
forval i = `range' {;	
di "ctry:`c', treatment:`t', var:`v', cat:`i', range:`range'";	
******************************************************************************;
qui bs mean = r(mean), reps(100) seed(010101) 
level(90): sum support if(ctry_num==`c'&treatcue==`t'&`v'==`i'); 
mat ci = e(ci_percentile); local lb = ci[1,1]; local ub = ci[2,1]; 
mat mean = e(b); local mean = mean[1,1]; mat N = e(N); local N = N[1,1]; 
******************************************************************************;
post `means' (`mean') (`lb') (`ub') (`N') (`V') (`t') (`i') (`c'); }; }; }; };  
******************************************************************************;
forval t = 0/1 {;
di "ctry: full, treatment:`t'";
******************************************************************************;
qui bs mean = r(mean), reps(100) seed(010101) 
level(90): sum support if(treatcue==`t'); 
mat ci = e(ci_percentile); local lb = ci[1,1]; local ub = ci[2,1]; 
mat mean = e(b); local mean = mean[1,1]; mat N = e(N); local N = N[1,1]; 
******************************************************************************;
post `means' (`mean') (`lb') (`ub') (`N') (0) (`t') (.) (0);  
******************************************************************************;
foreach v in incumbent party_old party_sys_old ambiguous_high {; 
if("`v'"=="incumbent"){; local V = 1; }; 
else if("`v'"=="party_old"){; local V = 2; }; 
else if("`v'"=="party_sys_old"){; local V = 3; };
else if("`v'"=="ambiguous_high"){; local V = 4; };  forval i = 0/1 {;	
di "ctry: full, treatment:`t', var:`v', cat:`i'";	
******************************************************************************;
bs mean = r(mean), reps(100) seed(010101) 
level(90): sum support if(treatcue==`t'&`v'==`i');  mat ci = e(ci_percentile); 
local lb = ci[1,1]; local ub = ci[2,1]; mat mean = e(b); 
local mean = mean[1,1]; mat N = e(N); local N = N[1,1]; 
******************************************************************************;
post `means' (`mean') (`lb') (`ub') (`N') (`V') (`t') (`i') (0); }; }; };  
postclose `means';

******************************************************************************;
* Graphing quantities of interest; 
use means, clear; 

preserve; keep if(v==0);
forval c = 0/3 {;
if(`c'==0){; local set "ti(Full, c(black) si(large))"; };
if(`c'==1){; local set "ysc(off) ti(GB, c(black) si(large))"; };
if(`c'==2){; local set "ysc(off) ti(HU, c(black) si(large))"; };
if(`c'==3){; local set "ysc(off) ti(PO, c(black) si(large))"; };
tw (bar mean t if(ctry==`c'), lc(black) fc(white) lw(thick))
(rspike lb ub t if(ctry==`c'), lc(gray) lw(thick)),
ysc(range(2.2 3.4)) ylab(2.4(.2)3.4) xsc(off) leg(off) `graphr' `set'
text(2.4 0 "Control") text(2.4 1 "Treat") 
name(plot`c', replace); }; 
gr combine plot0 plot1 plot2 plot3, `graphr' `grcom' rows(1)
l2(Mean of level of support, c(black) si(medium)); 
gr export fig1_leftPanel.pdf, replace;
gr export fig1_leftPanel.png, width(8260) height(6000) replace; restore;

replace t = 2 if(t==1); g tplus = t + .6; 
forval v = 1/4 {; local V = `v'+1; forval c = 0/3 {; 
if(`c'==0){; local set "ti(Full, c(black) si(large))"; 
local text1 "0"; local text2 "2"; };
if(`c'==1){; local set "ysc(off) ti(GB, c(black) si(large))"; 
local text1 "0"; local text2 "2"; };
if(`c'==2){; local set "ysc(off) ti(HU, c(black) si(large))"; 
local text1 ".6"; local text2 "2.6"; };
if(`c'==3){; local set "ysc(off) ti(PO, c(black) si(large))"; 
local text1 "0"; local text2 "2"; };
tw 
(bar mean tplus if(v==`v'&cat==0&ctry==`c'), lc(gray) fc(white) lw(thick))
(bar mean t if(v==`v'&cat==1&ctry==`c'), lc(black) fc(white) lw(thick))
(rspike lb ub t if(v==`v'&cat==1&ctry==`c'), lc(gray) lw(thick))
(rspike lb ub tplus if(v==`v'&cat==0&ctry==`c'), lc(gray) lw(thick)),
ysc(range(2.2 3.4)) ylab(2.2(.2)3.4) xsc(off) leg(off) `graphr' `set'
text(2.2 `text1' "C") text(2.2 `text2' "T") name(plot`c', replace); }; 
gr combine plot0 plot1 plot2 plot3, `graphr' `grcom' rows(1)
l2(Mean of level of support, c(black) si(medium)); 
gr export fig`V'_leftPanel.pdf, replace;
gr export fig`V'_leftPanel.png, width(8260) height(6000) replace; }; 

erase "means.dta";

******************************************************************************;
* Figure 1-5, right panel: Average treatment effect on level of support
******************************************************************************;
* Generating quantity of interest;
use data, clear;
keep if(partisan==1);
tempname diffs; postfile `diffs' diff lb ub N var cat ctry
using diffs, replace;
******************************************************************************;
forval c = 1/3 {; preserve; keep if(ctry_num==`c');
******************************************************************************;
qui bs diff = r(diff), reps(100) seed(010101) level(90): diff; 
mat ci = e(ci_percentile); local lb = ci[1,1]; local ub = ci[2,1]; 
mat diff = e(b); local diff = diff[1,1]; mat N = e(N); local N = N[1,1]; 
******************************************************************************;
post `diffs' (`diff') (`lb') (`ub') (`N') (0) (.) (`c'); restore;
******************************************************************************;
foreach v in incumbent party_old party_sys_old ambiguous_high {; 
if("`v'"=="incumbent"){; local V = 1; local range "0/1"; };
else if("`v'"=="party_old"){; local V = 2; local range "0/1"; 
if(`c'>=2){; local range "0/0"; }; else {; local range "0/1"; }; };
else if("`v'"=="party_sys_old"){; local V = 3; 
if(`c'==2){; local range "1/1"; }; else {; local range "0/1"; }; }; 
else if("`v'"=="ambiguous_high"){; local V = 4; 
if(`c'==2){; local range "0/0"; }; else {; local range "0/1"; }; }; 
forval i = `range' {; preserve; keep if(`v'==`i'&ctry_num==`c');
di "ctry:`c', var:`v', cat:`i', range:`range'";	
******************************************************************************;
qui bs diff = r(diff), reps(100) seed(010101) level(90): diff; 
mat ci = e(ci_percentile); local lb = ci[1,1]; local ub = ci[2,1]; 
mat diff = e(b); local diff = diff[1,1]; mat N = e(N); local N = N[1,1]; 
******************************************************************************;
post `diffs' (`diff') (`lb') (`ub') (`N') (`V') (`i') (`c'); restore; }; }; };
******************************************************************************;
qui bs diff = r(diff), reps(100) seed(010101) level(90): 
diff_overall; mat ci = e(ci_percentile); local lb = ci[1,1]; local ub = ci[2,1]; 
mat diff = e(b); local diff = diff[1,1]; mat N = e(N); local N = N[1,1]; 
******************************************************************************;
post `diffs' (`diff') (`lb') (`ub') (`N') (0) (.) (0);  
******************************************************************************;
foreach v in incumbent party_old party_sys_old ambiguous_high {; 
if("`v'"=="incumbent"){; local V = 1; }; 
else if("`v'"=="party_old"){; local V = 2; }; 
else if("`v'"=="party_sys_old"){; local V = 3; };
else if("`v'"=="ambiguous_high"){; local V = 4; };  forval i = 0/1 {;	
preserve; keep if(`v'==`i'); di "var:`v', cat:`i'";	
******************************************************************************;
qui bs diff = r(diff), reps(100) seed(010101) level(90): diff_overall; 
mat ci = e(ci_percentile); local lb = ci[1,1]; local ub = ci[2,1]; 
mat diff = e(b); local diff = diff[1,1]; mat N = e(N); local N = N[1,1];
******************************************************************************;
post `diffs' (`diff') (`lb') (`ub') (`N') (`V') (`i') (0); restore; }; };  
postclose `diffs';

******************************************************************************;
* Graphing quantities of interest; 
use diffs, clear; 

preserve; keep if(v==0); forval c = 0/3 {;
if(`c'==0){; local set "ysc(range(0 .3)) ylab(0(.1).3) ti(Full, c(black) 
si(large))"; };
if(`c'==1){; local set "ysc(off) ti(GB, c(black) si(large))"; };
if(`c'==2){; local set "ysc(off) ti(HU, c(black) si(large))"; };
if(`c'==3){; local set "ysc(off) ti(PO, c(black) si(large))"; };
tw (rcap lb ub ctry if(ctry==`c'), lc(black) lp(solid) lw(thick)) 
(scatter diff ctry if(ctry==`c'), mc(black) msiz(large)),
leg(off) `graphr' `set' xsc(off) yline(0, lc(black) lp(dash) lw(thick)) 
name(plot`c', replace); }; 
gr combine plot0 plot1 plot2 plot3, `graphr' ycommon imargin(zero) rows(1)
l1(Treatment effect on level of support, c(black) si(medium)); 
gr export fig1_rightPanel.pdf, replace;
gr export fig1_rightPanel.png, width(8260) height(6000) replace; 
restore;

g zero = 0; g ctry0 = .; forval c = 0/3 {;
replace ctry0 = ctry - .1 - `c' if(cat==1&ctry==`c'); 
replace ctry0 = ctry + .1 - `c' if(cat==0&ctry==`c'); };
g ctry00 = .5 if(zero==0&cat==0); replace ctry00 = -.5 if(zero==0&cat==1);
forval v = 1/4 {; local V = `v'+1; forval c = 0/3 {; 
if(`c'==0){; local set "ti(Full, c(black) si(large))"; };
if(`c'==1){; local set "ysc(off) ti(GB, c(black) si(large))"; };
if(`c'==2){; local set "ysc(off) ti(HU, c(black) si(large))"; };
if(`c'==3){; local set "ysc(off) ti(PO, c(black) si(large))"; };
tw (rspike lb ub ctry0 if(v==`v'&cat==1&ctry==`c'), lc(black) lw(thick))
(rspike lb ub ctry0 if(v==`v'&cat==0&ctry==`c'), lc(gray) lw(thick))
(scatter diff ctry0 if(v==`v'&cat==0&ctry==`c'), mc(gray) msiz(large))
(scatter diff ctry0 if(v==`v'&cat==1&ctry==`c'), mc(black) msiz(large))
(line zero ctry00, lc(none)),
ysc(range(0 .5)) ylab(0(.1).5) xsc(off) leg(off) `graphr' `set'
yline(0, lc(black) lp(dash) lw(thick)) name(plot`c', replace); }; 
gr combine plot0 plot1 plot2 plot3, `graphr' ycommon imargin(zero) rows(1)
l2(Treatment effect on level of support, c(black) si(medium)); 
gr export fig`V'_rightPanel.pdf, replace;
gr export fig`V'_rightPanel.png, width(8260) height(6000) replace; };

erase "diffs.dta";

*=================================================================================================;
* Figure 6: Means of standard deviation in left–right placement of parties by partisans by 
* categories (incumbent vs opposition party, old vs new party, old vs new party relative to party 
* system age, ideological ambiguous vs coherent party)
*=================================================================================================;
use data, clear;
keep if(partisan==1);

tempname cond_means; postfile `cond_means' mean lb ub N var inc using cond_means, replace;
******************************************************************************;
foreach v in party_old party_sys_old incumbent {; 
if("`v'"=="party_old"){; local V = 1; }; 
else if("`v'"=="party_sys_old"){; local V = 2; };
else if("`v'"=="incumbent"){; local V = 3; }; forval i = 0/1 {; 
******************************************************************************;
qui bs mean = r(mean), reps(100) seed(010101) 
level(90): sum idcohpar if(`v'==`i');  mat ci = e(ci_percentile); 
local lb = ci[1,1]; local ub = ci[2,1]; mat mean = e(b); 
local mean = mean[1,1]; mat N = e(N); local N = N[1,1]; 
******************************************************************************;
post `cond_means' (`mean') (`lb') (`ub') (`N') (`V') (`i'); }; };  
postclose `cond_means';

use cond_means, clear; 
forval v = 1/3 {; 
if(`v'==1){; local set "ti(Party age, c(black) si(medium))
ysc(range(1.8 2.4)) ylab(1.8(.1)2.3) text(2.35 0 "Young")
text(2.35 1 "Old")"; }; 
else if(`v'==2){; local set "ti(Systemic party age, c(black) si(medium)) 
ysc(off) text(2.35 0 "Young") text(2.35 1 "Old")"; }; 
else if(`v'==3){; local set "ti(Incumbency Status, c(black) si(medium)) 
ysc(off) text(2.35 0 "Opposition") text(2.35 1 "Incumbent")"; }; 

tw (bar mean inc if(v==`v'&inc==1), lc(black) fc(white) lw(thick))
(bar mean inc if(v==`v'&inc==0), lc(black) fc(white) lw(thick))
(rspike lb ub inc if(v==`v'&inc==1), lc(gray) lw(thick))
(rspike lb ub inc if(v==`v'&inc==0), lc(gray) lw(thick)),
leg(off) `graphr' `set' xsc(off) name(plot`v', replace); }; 
gr combine plot1 plot2 plot3, `graphr' `grcom' rows(1)
l1(Standard deviation in left-right placement, c(black) si(medium));
gr export fig6.pdf, replace;
gr export fig6.png, replace; 

erase "cond_means.dta";

*=================================================================================================;
* Table 2. Tobit regression of support on various specifications of dummy treated, party age,
* incumbency status, ideological coherence, and country dummies 
*=================================================================================================;
use data, clear; 
keep if(partisan==1);
tobit support treatcue hu po party_age treathu treatpo treatparty_age, 
ll(1) ul(5) vce(cl ctry_num); 
outreg2 using "table2.tex", replace tex(frag) bdec(4) onecol;
tobit support treatcue hu po party_age incumbent idcohpar treathu treatpo 
treatparty_age treatinc treatidcohpar, ll(1) ul(5) vce(cl ctry_num);  
outreg2 using "table2.tex", append tex(frag) bdec(4) onecol;
tobit support treatcue hu po party_age incumbent idcohpar incidcohpar 
party_ageidcohpar treathu treatpo treatparty_age treatinc treatidcohpar 
treatparty_ageidcohpar treatincidcohpar, ll(1) ul(5) vce(cl ctry_num);  
outreg2 using "table2.tex", append tex(frag) bdec(4) onecol;

*=================================================================================================;
* Figure 7. Expected values of level of support for control and treatment group by incumbency 
* status and country (party age is at its mean)
*=================================================================================================;
use data, clear; 
keep if(partisan==1);

tempname exp_values; postfile `exp_values' ev t inc id age ctry it
using exp_values, replace; quietly {; sum party_age; 
local age = r(mean); sum support; local N = r(N)-1; }; forval it = 1/100 {;  
preserve; bsample `N'; 
******************************************************************************;
qui tobit support treatcue hu po party_age incumbent idcohpar 
incidcohpar party_ageidcohpar treathu treatpo treatparty_age 
treatinc treatidcohpar treatparty_ageidcohpar treatincidcohpar, 
ll(1) ul(5) robust; mat b = e(b);
******************************************************************************;
forval t = 0/1 {;  forval i = 0/1 {; forval id0 = 10/30 {; 
local id = `id0'/10;
di "ctry: 1, treatment:`t' incumbent:`i', id:`id', var:idcohpar, it: `it'"; 
******************************************************************************;
local xb = b[1,16] + b[1,1]*`t' + b[1,4]*`age' + b[1,5]*`i' + b[1,6]*`id' + 
b[1,7]*`i'*`id' + b[1,8]*`age'*`id' + b[1,11]*`t'*`age' + b[1,12]*`t'*`i' +
b[1,13]*`t'*`id' + b[1,14]*`t'*`age'*`id' + b[1,15]*`t'*`i'*`id';
local a = (1-`xb')/b[1,17]; local b = (5-`xb')/b[1,17];
local p = normal(`b') - normal(`a');
local e = `xb' + b[1,17]*(normalden(`a')/`p') - b[1,17]*(normalden(`b')/`p');
local ev = normal(`a')*1 + (1-normal(`b'))*5 + `p'*`e';
post `exp_values' (`ev') (`t') (`i') (`id') (`age') (1) (`it'); 
******************************************************************************;
di "ctry: 2, treatment:`t' incumbent:`i', id:`id', var:idcohpar, it: `it'"; 
******************************************************************************;
local xb = b[1,16] + b[1,1]*`t' + b[1,2] + b[1,4]*`age' + b[1,5]*`i' + 
b[1,6]*`id' + b[1,7]*`i'*`id' + b[1,8]*`age'*`id' + b[1,9]*`t' + 
b[1,11]*`t'*`age' + b[1,12]*`t'*`i' + b[1,13]*`t'*`id' + 
b[1,14]*`t'*`age'*`id' + b[1,15]*`t'*`i'*`id';
local a = (1-`xb')/b[1,17]; local b = (5-`xb')/b[1,17];
local p = normal(`b') - normal(`a');
local e = `xb' + b[1,17]*(normalden(`a')/`p') - b[1,17]*(normalden(`b')/`p');
local ev = normal(`a')*1 + (1-normal(`b'))*5 + `p'*`e';
post `exp_values' (`ev') (`t') (`i') (`id') (`age') (2) (`it'); 
******************************************************************************;
di "ctry: 3, treatment:`t' incumbent:`i', id:`id', var:idcohpar, it: `it'"; 
******************************************************************************;
local xb = b[1,16] + b[1,1]*`t' + b[1,3] + b[1,4]*`age' + b[1,5]*`i' + 
b[1,6]*`id' + b[1,7]*`i'*`id' + b[1,8]*`age'*`id' + b[1,10]*`t' + 
b[1,11]*`t'*`age' + b[1,12]*`t'*`i' + b[1,13]*`t'*`id' + 
b[1,14]*`t'*`age'*`id' + b[1,15]*`t'*`i'*`id';
local a = (1-`xb')/b[1,17]; local b = (5-`xb')/b[1,17];
local p = normal(`b') - normal(`a');
local e = `xb' + b[1,17]*(normalden(`a')/`p') - b[1,17]*(normalden(`b')/`p');
local ev = normal(`a')*1 + (1-normal(`b'))*5 + `p'*`e';
post `exp_values' (`ev') (`t') (`i') (`id') (`age') (3) (`it');
******************************************************************************;
}; }; }; restore; }; postclose `exp_values';

use exp_values, clear; 
g lb = ev; g ub = ev; 
collapse (mean) ev (p5) lb (p95) ub, by(inc age id t ctry);
save exp_values0, replace;

use exp_values0, clear; 
g idplus = id + .005;
la var ev " "; la var lb " ";  la var ub " ";  la var id " "; 
la var idplus " ";
forval c = 1/3 {; forval i = 0/1 {; 
if(`c'==1&`i'==0){; local set "ti(GB, c(black) si(medium)) xsc(off)"; };
else if(`c'==2&`i'==0){; local set "ti(HU, c(black) si(medium)) xsc(off)
ysc(off)"; };
else if(`c'==3&`i'==0){; local set "ti(PO, c(black) si(medium)) xsc(off)
ysc(off) r1(Opposition, c(black) si(medium))"; };
else if(`c'==1&`i'==1){; local set " "; };
else if(`c'==2&`i'==1){; local set "ysc(off)"; };
else if(`c'==3&`i'==1){; local set "ysc(off) 
r1(Incumbent, c(black) si(medium))"; };
tw 
(line ev id if(c==`c'&inc==`i'&t==1), lc(black) lp(solid) lw(thick))
(line ev id if(c==`c'&inc==`i'&t==0), lc(gray) lp(solid) lw(thick))
(rspike lb ub id if(c==`c'&inc==`i'&t==1), lc(black) lp(solid) lw(thin))
(rspike lb ub idplus if(c==`c'&inc==`i'&t==0), lc(gray) lp(solid) lw(thin)),
`graphr' `set' leg(off) name(plot`c'_`i', replace); }; }; 

gr combine plot1_0 plot2_0 plot3_0, `graphr' ycommon xcommon imargin(medium) 
rows(1) name(plot1, replace);
gr combine plot1_1 plot2_1 plot3_1, `graphr' ycommon xcommon imargin(medium) 
rows(1) name(plot2, replace);
gr combine plot1 plot2, `graphr' ycommon xcommon imargin(medium) rows(2)
l2(Expected level of support, c(black) si(medium)) 
b1(Standard deviation in left-right placement, c(black) si(medium));
gr export fig7.pdf, replace;
gr export fig7.png, replace;

*=================================================================================================;
* Robustness of results in Table 2
*=================================================================================================; 
* Tobit regression with frequency weights by country;
use data, clear; 
keep if(partisan==1);
tobit support treatcue hu po party_age treathu treatpo treatparty_age [fw=ctry_num], 
ll(1) ul(5) vce(cl ctry_num); 
outreg2 using "table2_fweights.tex", replace tex(frag) bdec(4) onecol;
tobit support treatcue hu po party_age incumbent idcohpar treathu treatpo 
treatparty_age treatinc treatidcohpar [fw=ctry_num], ll(1) ul(5) vce(cl ctry_num);  
outreg2 using "table2_fweights.tex", append tex(frag) bdec(4) onecol;
tobit support treatcue hu po party_age incumbent idcohpar incidcohpar 
party_ageidcohpar treathu treatpo treatparty_age treatinc treatidcohpar 
treatparty_ageidcohpar treatincidcohpar [fw=ctry_num], ll(1) ul(5) vce(cl ctry_num);  
outreg2 using "table2_fweights.tex", append tex(frag) bdec(4) onecol;

* OLS (also in Appendix as Table D2);
reg support treatcue hu po party_age treathu treatpo treatparty_age, 
vce(cl ctry_num); 
outreg2 using "appendix_tableD1.tex", replace 
tex(frag) bdec(4) onecol;
reg support treatcue hu po party_age incumbent idcohpar treathu treatpo 
treatparty_age treatinc treatidcohpar, vce(cl ctry_num); 
outreg2 using "appendix_tableD1.tex", append 
tex(frag) bdec(4) onecol;
reg support treatcue hu po party_age incumbent idcohpar incidcohpar 
party_ageidcohpar treathu treatpo treatparty_age treatinc treatidcohpar 
treatparty_ageidcohpar treatincidcohpar, vce(cl ctry_num);  
outreg2 using "appendix_tableD1.tex", append 
tex(frag) bdec(4) onecol;

tobit support treatcue hu po party_sys_age treathu treatpo treatparty_sys_age, 
ll(1) ul(5) vce(cl ctry_num); 
outreg2 using "appendix_tableD2.tex", replace 
tex(frag) bdec(4) onecol;
tobit support treatcue hu po party_sys_age incumbent idcohpar treathu treatpo 
treatparty_sys_age treatinc treatidcohpar, ll(1) ul(5) vce(cl ctry_num); 
outreg2 using "appendix_tableD2.tex", append 
tex(frag) bdec(4) onecol;
tobit support treatcue hu po party_sys_age incumbent idcohpar incidcohpar 
party_sys_ageidcohpar treathu treatpo treatparty_sys_age treatinc treatidcohpar 
treatparty_sys_ageidcohpar treatincidcohpar, ll(1) ul(5) vce(cl ctry_num); 
outreg2 using "appendix_tableD2.tex", append 
tex(frag) bdec(4) onecol;

reg support treatcue hu po party_sys_age treathu treatpo treatparty_sys_age, 
vce(cl ctry_num);  
outreg2 using "appendix_tableD3.tex", replace tex(frag) bdec(4) onecol;
reg support treatcue hu po party_sys_age incumbent idcohpar treathu treatpo 
treatparty_sys_age treatinc treatidcohpar, vce(cl ctry_num); 
outreg2 using "appendix_tableD3.tex", append tex(frag) bdec(4) onecol;
reg support treatcue hu po party_sys_age incumbent idcohpar incidcohpar 
party_sys_ageidcohpar treathu treatpo treatparty_sys_age treatinc treatidcohpar 
treatparty_sys_ageidcohpar treatincidcohpar, vce(cl ctry_num); 
outreg2 using "appendix_tableD3.tex", append tex(frag) bdec(4) onecol;

* Correlation between measurse of ideological ambiguity;
pwcorr idcoh idcohpar, sig; pwcorr idcoh idcohprefpar, sig; 
pwcorr idcohpar idcohprefpar, sig; pwcorr idcoh benoitlaver, sig; 
pwcorr idcohpar benoitlaver, sig; pwcorr idcohprefpar benoitlaver, sig; 

*=================================================================================================;
*=================================================================================================;
exit;
*=================================================================================================;
*=================================================================================================;
*=================================================================================================;
